==> N73.423.jar: CG3.m <==
V@ 
bg_jinjingddd  CG   @   siguo   
bg_jinjingddd         
moveback1_598 bg_jinjingddd10         moveback2_2400  script:999{
effect(1)
wait(10)
}
script:1000{
intro(孙中山、咸马里、四国(英、美、法、德)银行团主任、英国外交大臣葛雷、道森。,,)
effect(2)
wait(10)
dialog(我想见英、美、法、德四个国家银行领导人，我需要和他们谈谈。,tx.an,sunzhongshan, 孙中山,down)
dialog(如果你想见这四个国家的银行领导人，那就不必了。,tx.an,heiren,？？？,up)
dialog(为什么？,tx.an,sunzhongshan, 孙中山,down)
dialog(因为没有这个必要，你只要见一个人就可以了。,tx.an,heiren,？？？,up)
dialog(谁？会有这么大的能力。,tx.an,sunzhongshan, 孙中山,down)
dialog(四国(英、美、法、德)银行团主任。我会为你引见他。,tx.an,heiren,？？？,up)
dialog(谢谢，此恩铭记一生。,tx.an,sunzhongshan, 孙中山,down)
effect(1)
wait(10)
intro(就这样，孙中山在美国军事研究家咸马里介绍下，与四国(英、美、法、德)银行团主任会晤，商谈停止对清政府的贷款问题。,sunzhongshan,孙中山)
effect(2)
wait(10)
dialog(您好，是银行团主任吧？,tx.an,sunzhongshan, 孙中山,down)
dialog(是的，你就是威马里介绍来的孙先生吧。,tx.an,heiren,？？？,up)
dialog(请讲。,tx.an,heiren,？？？,up)
dialog(我国内正在闹革命，我希望四国支持。银行团停止交付辛亥革命前同清政府签订的关于粤汉、川汉铁路的600万英镑贷款，停止发行币制实业贷款1000万英镑的债券。,tx.an,sunzhongshan, 孙中山,down)
dialog(对不起孙先生。对华贷款问题由英国外交大臣作主，我是无任何权力参与这件事的。你必须找到英国外交大臣葛雷，他才有决定权。,tx.an,heiren,？？？,up)
dialog(我在哪里才能找到他？,tx.an,sunzhongshan, 孙中山,down)
dialog(我会想办法的。,tx.an,heiren,？？？,up)
dialog(那就先谢谢你了。,tx.an,sunzhongshan, 孙中山,down)
effect(1)
wait(10)
intro(与银行团主任会晤后无果，孙中山并没有放弃。他决定一定找到英国外交大臣葛雷，于是又托维加炮厂经理道森作为他的代表，向英国外交大臣葛雷进行交涉。向英国政府提出三点要求：一、停止对清廷的一切贷款；二、制止日本援助清廷；三、取消亚洲各国英属殖民当局对他的放逐令，以便取道回国。英国政府表示同意孙中山的上述要求。带着这样兴奋的消息，孙中山有找到了银行团主任。,sunzhongshan,孙中山)
effect(2)
wait(10)
dialog(团主任您好，我又来拜访了！,tx.an,sunzhongshan, 孙中山,down)
dialog(您好。,tx.an,heiren,？？？,up)
dialog(我委托道森先生与葛雷大臣交涉过了，他们同意了。,tx.an,sunzhongshan, 孙中山,down)
dialog(我们已经接到通知了，关于粤汉、川汉铁路的600万英镑贷款和贷款1000万英镑的债券，均已按照上级要求停止实施了。,tx.an,heiren,？？？,up)
dialog(我还有一要求，希望团主任可以应允。,tx.an,sunzhongshan, 孙中山,down)
dialog(说来听听。,tx.an,heiren,？？？,up)
dialog(我希望银行团贷款给中国革命政府，支持革命事业。,tx.an,sunzhongshan, 孙中山,down)
dialog(孙先生，您所谓的中国革命政府，不是正式政府，按照规定我们是无法贷贷款给您的，请您见谅。,tx.an,heiren,？？？,up)
dialog(知道了，再次感谢。,tx.an,sunzhongshan, 孙中山,down)
effect(1)
wait(10)
dialog(唉！你又怎会知道，我接到的命令只是敷衍你，政府答应你的事，根本就没有去做。,tx.an,heiren,？？？,up)
intro(1911年11月，孙中山为切断外国与清政府的资金流动，同时给革命军筹集起义款项，奔波于国外各处。而外国人又怎会理解革命之辛苦?他们只要有利益就会不择手段谋取，又怎会过多的帮助革命军？但是革命是必然的趋势，很多华人华侨，他们宁可倾家荡产，也要支持革命。在社会各界的帮助下，革命的号角又一次打响了。,sunzhongshan,孙中山)
loadmap(c03,25,236,nopj)
}

==> N5800.68.jar: CG3.m <==
V@ 
bg_jinjingddd  CG   @   siguo   
bg_jinjingddd         
moveback1_598 bg_jinjingddd10         moveback2_2400  script:999{
effect(1)
wait(10)
}
script:1000{
intro(孙中山、咸马里、四国(英、美、法、德)银行团主任、英国外交大臣葛雷、道森。,,)
effect(2)
wait(10)heiren,？？？,up
dialog(我想见英、美、法、德四个国家银行领导人，我需要和他们谈谈。,tx.an,sunzhongshan, 孙中山,down)
dialog(如果你想见这四个国家的银行领导人，那就不必了。,tx.an,heiren,？？？,up)
dialog(为什么？,tx.an,sunzhongshan, 孙中山,down)
dialog(因为没有这个必要，你只要见一个人就可以了。,tx.an,heiren,？？？,up)
dialog(谁？会有这么大的能力。,tx.an,sunzhongshan, 孙中山,downp)
dialog(四国(英、美、法、德)银行团主任。我会为你引见他。,tx.an,heiren,？？？,up)
dialog(谢谢，此恩铭记一生。,tx.an,sunzhongshan, 孙中山,down)
effect(1)
wait(10)
intro(就这样，孙中山在美国军事研究家咸马里介绍下，与四国(英、美、法、德)银行团主任会晤，商谈停止对清政府的贷款问题。,sunzhongshan,孙中山)
effect(2)
wait(10)
dialog(您好，是银行团主任吧？,tx.an,sunzhongshan, 孙中山,down)
dialog(是的，你就是威马里介绍来的孙先生吧。,tx.an,heiren,？？？,up)
dialog(请讲。,tx.an,heiren,？？？,up)
dialog(我国内正在闹革命，我希望四国支持。银行团停止交付辛亥革命前同清政府签订的关于粤汉、川汉铁路的600万英镑贷款，停止发行币制实业贷款1000万英镑的债券。,tx.an,sunzhongshan, 孙中山,down)
dialog(对不起孙先生。对华贷款问题由英国外交大臣作主，我是无任何权力参与这件事的。你必须找到英国外交大臣葛雷，他才有决定权。,tx.an,heiren,？？？,up)
dialog(我在哪里才能找到他？,tx.an,sunzhongshan, 孙中山,down)
dialog(我会想办法的。,tx.an,heiren,？？？,up)
dialog(那就先谢谢你了。,tx.an,sunzhongshan, 孙中山,down)
effect(1)
wait(10)
intro(与银行团主任会晤后无果，孙中山并没有放弃。他决定一定找到英国外交大臣葛雷，于是又托维加炮厂经理道森作为他的代表，向英国外交大臣葛雷进行交涉。向英国政府提出三点要求：一、停止对清廷的一切贷款；二、制止日本援助清廷；三、取消亚洲各国英属殖民当局对他的放逐令，以便取道回国。英国政府表示同意孙中山的上述要求。带着这样兴奋的消息，孙中山有找到了银行团主任。,sunzhongshan,孙中山)
effect(2)
wait(10)
dialog(团主任您好，我又来拜访了！,tx.an,sunzhongshan, 孙中山,down)
dialog(您好。,tx.an,heiren,？？？,up)
dialog(我委托道森先生与葛雷大臣交涉过了，他们同意了。,tx.an,sunzhongshan, 孙中山,down)
dialog(我们已经接到通知了，关于粤汉、川汉铁路的600万英镑贷款和贷款1000万英镑的债券，均已按照上级要求停止实施了。,tx.an,heiren,？？？,up)
dialog(我还有一要求，希望团主任可以应允。,tx.an,sunzhongshan, 孙中山,down)
dialog(说来听听。,tx.an,heiren,？？？,up)
dialog(我希望银行团贷款给中国革命政府，支持革命事业。,tx.an,sunzhongshan, 孙中山,down)
dialog(孙先生，您所谓的中国革命政府，不是正式政府，按照规定我们是无法贷贷款给您的，请您见谅。,tx.an,heiren,？？？,up)
dialog(知道了，再次感谢。,tx.an,sunzhongshan, 孙中山,down)
effect(1)
wait(10)
dialog(唉！你又怎会知道，我接到的命令只是敷衍你，政府答应你的事，根本就没有去做。,tx.an,heiren,？？？,up)
intro(1911年11月，孙中山为切断外国与清政府的资金流动，同时给革命军筹集起义款项，奔波于国外各处。而外国人又怎会理解革命之辛苦?他们只要有利益就会不择手段谋取，又怎会过多的帮助革命军？但是革命是必然的趋势，很多华人华侨，他们宁可倾家荡产，也要支持革命。在社会各界的帮助下，革命的号角又一次打响了。,sunzhongshan,孙中山)
loadmap(c03,25,236,nopj)
}
